@@ -1,3 +1,4 @@
+# Copyright (c) OpenMMLab. All rights reserved.
 import os.path as osp
 import warnings
 
@@ -34,7 +35,7 @@ class DeployBaseDetector(BaseDetector):
     def train_step(self, data, optimizer):
         raise NotImplementedError('This method is not implemented.')
 
-    def aforward_test(self, *, img, img_metas, **kwargs):
+    def forward_test(self, *, img, img_metas, **kwargs):
         raise NotImplementedError('This method is not implemented.')
 
     def async_simple_test(self, img, img_metas, **kwargs):
@@ -81,7 +82,7 @@ class DeployBaseDetector(BaseDetector):
                     masks = torch.nn.functional.interpolate(
                         masks.unsqueeze(0), size=(ori_h, ori_w))
                     masks = masks.squeeze(0).detach().numpy()
-                if masks.dtype != np.bool:
+                if masks.dtype != bool:
                     masks = masks >= 0.5
                 segms_results = [[] for _ in range(len(self.CLASSES))]
                 for j in range(len(dets)):
